@@ -24,7 +24,6 @@ sub describe_log_groups {
   my ( $self, $log_group_name, $query ) = @_;
 
   $log_group_name //= $self->get_log_group_name;
-  $log_group_name = "$log_group_name/";
 
   return $self->command( 'describe-log-groups' =>
       [ $log_group_name ? ( '--log-group-name-prefix' => $log_group_name ) : (), $query ? ( '--query' => $query ) : () ] );
@@ -49,7 +48,7 @@ sub log_group_exists {
   $log_group_name //= $self->get_log_group_name;
 
   # Check if log group exists already
-  my $result = $self->describe_log_groups( $log_group_name, 'logGroups' );
+  my $result = $self->describe_log_groups( $log_group_name, sprintf 'logGroups[?logGroupName == `%s`]', $log_group_name );
 
   return
     if !$result || !@{$result};
